.. _setup:

Setup
=====

Before writing the plugin, make sure that you have access to all the appropriate
programs and libraries. Ensure python installed and that your pythonpath
points to '/path/to/hydra/platform/HydraPlatform/HydraLib'. This example does
not use any other libraries, so no other setup should be necessary.

For help setting up your pythonpath, look `here <https://docs.python.org/2/using/windows.html#configuring-python>`_ or `here <http://www.google.com/search?q=how+to+set+pythonpath>`_.

This will give you access to some utility functions which will make it easier
to create your plugin. We won't delve into these here, but feel free to look!

Next, create a python file called ExportJSON.py in an appropriate folder.

Now we are ready to start writing our plugin.


